c
      subroutine element(x,y,x1,y1,x2,y2,dxx,sig,idble,dip,
     +                   F1,F2,F3,fxx,fyy,fzz)
c
      implicit real*8(a-h,o-z)
c
      common/plate/rlam1,rlam2,rmu1,rmu2,rho,rc,rd,alph,pi
c
c       create the force vector for this element
c
c       input:
c
c       x, y    - computation point      (km)
c       x1,y1   - start position         (km)
c       x2,y2   - end position           (km)
c       dxx     - grid spacing           (km)
c       sig     - source width in pixels (try 1)
c       idble   - (0-single couple, 1-double couple)
c       F1      - strike-slip
c       F2      - dip-slip
c       F3      - opening mode
c
c       output:
c
c       fxx     - x-component of force couple
c       fyy     - y-component of force couple
c       fzz     - z-component of force couple
c
c  set the x and y taper lengths
c
      sigy=sig

c  sigx  should be = 2 or perhaps 4
c
      sigx=2.0
c
c  compute the length and orientation of the fault
c
      Dx=(x2-x1) 
      Dy=(y2-y1) 
      L=sqrt(Dx*Dx+Dy*Dy) 
      theta=atan2(Dy,Dx) 
      st=sin(theta) 
      ct=cos(theta) 
c
c  rotate the vector into the model space
c
      x0=x-x1 
      y0=y-y1 
      xp=x0*ct+y0*st 
      yp=-x0*st+y0*ct 
 
c  compute the h and dh/dx functions
c
      h=exp(-0.5*((yp/sigy)**2))/(sqrt(2*pi)*sigy)/(dxx*dxx) 
      dh=-yp*exp(-0.5*((yp/sigy)**2))/(sqrt(2*pi)*sigy**3)/(dxx*dxx) 
c
c   compute the g and dgdx functions
c
      if(xp .gt. -sigx .and. xp .lt. sigx) then
         g=0.5*(1-cos(pi*(xp+sigx)/(2*sigx))) 
         dg=pi*sin(pi*(xp+sigx)/(2*sigx))/(4*sigx)
      else if(xp .ge. sigx .and. xp .le. L-sigx) then
         g=1. 
         dg=0.
      else if(xp .gt. L-sigx .and. xp .lt. L+sigx) then
         g=0.5*(1-cos(pi*(L+sigx-xp)/(2*sigx))) 
         dg=-pi*sin(pi*(L+sigx-xp)/(2*sigx))/(4*sigx)
      else
         g=0. 
         dg=0.
      endif

c
c extract components
c
c this subroutine is used  for:
c	F1 single and double couple 
c	F2 single couple
c	F3 single couple and double couple in fxx/fyy direction

c scale F1 and F2 by shear modulus
c note:  F3 needs to be treated differently

      F1s=rmu1*F1
      F2s=rmu1*F2

c assing scaling factor for dipping faults

      phi=dip*(pi/180)
      s2p=sin(2*phi) 
      c2p=cos(2*phi)
      
c      print*,s2p, c2p

c  primary couple
c
c      pfxx=g*dh*(-F1s*ct+(rlam1+2*rmu1)*F3*st)
c      pfyy=g*dh*( F1s*st+(rlam1+2*rmu1)*F3*ct)
c      pfzz=g*dh*F2s 

      pfxx=g*dh*(-F1s*ct-(F2s*st*s2p)+(rlam1+2*rmu1)*F3*st)
      pfyy=g*dh*( F1s*st-(F2s*ct*s2p)+(rlam1+2*rmu1)*F3*ct)
      pfzz=g*dh*F2s*(-c2p)
      
      sfxx=0.
      sfyy=0.
      sfzz=0.
   
c           
c  secondary couple(s)
c
      if(idble.eq.1) then
	
c implement initial round of double couple computation 
c if supplement couples are required, go to element2.f

        sfxx=dg*h*(F1s*st + rlam1*-F3*ct)
        sfyy=dg*h*(F1s*ct + rlam1*F3*st)     
	sfzz=0.
        
      endif

c sum the primary and secondary couples (double couple)

	fxx=pfxx+sfxx
	fyy=pfyy+sfyy
	fzz=pfzz+sfzz
      
      
      return
      end
        
	
	
